@@ -10,6 +10,7 @@ from typing import BinaryIO, Dict
 
 import click
 import rich.console as rich_console
+import uvicorn
 import validators
 
 import fixieai.client
@@ -223,12 +224,18 @@ def _ensure_agent_updated(
     "--tunnel/--no-tunnel",
     is_flag=True,
     default=True,
-    help="Create a tunnel using localhost.run",
+    help="(default enabled) Create a tunnel using localhost.run.",
+)
+@click.option(
+    "--reload/--no-reload",
+    is_flag=True,
+    default=True,
+    help="(default enabled) Reload automatically.",
 )
 @click.pass_context
-def serve(ctx, path, host, port, tunnel):
+def serve(ctx, path, host, port, tunnel, reload):
     console = rich_console.Console()
-    config, agent_impl = loader.load_agent_from_path(path)
+    config = agent_config.load_config(path)
 
     with contextlib.ExitStack() as stack:
         if tunnel:
@@ -238,10 +245,26 @@ def serve(ctx, path, host, port, tunnel):
                 f"[yellow]This replaces any existing deployment, run [bold]fixie deploy[/bold] to redeploy to prod.[/yellow]"
             )
             config.deployment_url = stack.enter_context(tunnel_.Tunnel(host, port))
-            console.print(f"{host}:{port} can be reached at {config.deployment_url}")
 
         agent_api = _ensure_agent_updated(ctx.obj.client, config)
-        agent_impl.serve(agent_api.agent_id, host, port)
+        console.print(
+            f"🦊 Agent [green]{agent_api.agent_id}[/] running locally on {host}:{port}, served via {agent_api.func_url}"
+        )
+
+        if reload:
+            os.environ["FIXIE_REFRESH_AGENT_ID"] = agent_api.agent_id
+            uvicorn.run(
+                config.entry_point + ".app",
+                host=host,
+                port=port,
+                factory=True,
+                reload=True,
+                reload_dirs=[os.path.dirname(path)],
+                app_dir=os.path.dirname(path),
+            )
+        else:
+            _, agent_impl = loader.load_agent_from_path(path)
+            agent_impl.serve(agent_api.agent_id, host, port)
 
 
 _DEPLOYMENT_BOOTSTRAP_SOURCE = """
@@ -329,7 +352,9 @@ def deploy(ctx, path, metadata_only):
     else:
         suggested_query = "Hello!"
 
-    suggested_message = shlex.quote(f"@{agent_api.agent_id} {suggested_query}")
+    suggested_command = (
+        f"fixie console --agent {agent_api.agent_id} {shlex.quote(suggested_query)}"
+    )
     console.print(
-        f"Your agent was deployed to {constants.FIXIE_API_URL}/agents/{agent_api.agent_id}\nYou can also chat with your agent using the fixie CLI:\n\nfixie console {suggested_message}"
+        f"Your agent was deployed to {constants.FIXIE_API_URL}/agents/{agent_api.agent_id}\nYou can also chat with your agent using the fixie CLI:\n\n{suggested_command}"
     )
